import _extends from "@babel/runtime/helpers/esm/extends";
import React, { useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeButtonGroupField from '@s-ui/react-molecule-button-group-field';
import Button from '@s-ui/react-atom-button';

var InlineButton = function InlineButton(_ref) {
  var inlineButton = _ref.inlineButton,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[inlineButton.id];
  var alertMessages = alerts[inlineButton.id];
  var datalist = inlineButton.datalist;

  var onClickHandler = function onClickHandler(value) {
    return onChange(inlineButton.id, value);
  };

  var onChangeCallback = useCallback(function (value) {
    return onChange(inlineButton.id, value);
  }, [onChange, inlineButton]);

  var inlineButtonProps = _extends({
    id: inlineButton.id,
    label: inlineButton.label,
    tabIndex: tabIndex,
    value: inlineButton.value || '',
    onChange: onChangeCallback
  }, inlineButton.disabled && {
    disabled: true
  }, {}, inlineButton.hidden && {
    hidden: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, {}, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (inlineButtonProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: inlineButton.id,
    innerProps: _extends({}, inlineButtonProps, {
      datalist: datalist
    })
  }); // render custom component

  if (React.isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-InlineButton sui-FormBuilder-" + (inlineButtonProps.id || tabIndex)
  }, React.createElement(MoleculeButtonGroupField, Object.assign({}, inlineButtonProps, rendererResponse), datalist.map(function (button) {
    return React.createElement(Button, {
      key: button.text,
      design: button.value === inlineButton.value ? 'solid' : 'outline',
      onClick: function onClick() {
        return onClickHandler(button.value);
      },
      isSubmit: false,
      isButton: true
    }, button.text);
  })));
};

InlineButton.displayName = 'InlineButton';
export default React.memo(InlineButton, createComponentMemo('inlineButton'));